start

# po2wordfast

Convert Gettext PO files to a Wordfast translation memory file.

Wordfast is a popular Windows based computer-assisted translation tool.

## Usage

    po2wordfast [options] --language <target> <po> <wordfast>

Where:

<po> | a PO file or directory
<wordfast> | a Wordfast translation memory file

Options:

--version | show program's version number and exit
-h, --help | show this help message and exit
--manpage | output a manpage based on the help
--progress=PROGRESS | show progress as: dots, none, bar, names, verbose
--errorlevel=ERRORLEVEL | show errorlevel as: none, message, exception, traceback
-iINPUT, --input=INPUT | read from INPUT in po, pot formats
-xEXCLUDE, --exclude=EXCLUDE | exclude names matching EXCLUDE from input paths
-oOUTPUT, --output=OUTPUT | write to OUTPUT in tmx format
--psyco=MODE | use psyco to speed up the operation, modes: none, full, profile
-lLANG, --language=LANG | set target language code (e.g. af-ZA) [required]
--source-language=LANG | set source language code (default: en)

## Examples

    po2wordfast -l xh-ZA browser.po browser.txt

Use the Xhosa (xh-ZA) translations in the PO file browser.po to create a Wordfast translation memory file called browser.txt